
/**
 * IM 集成JSSDK
 * @param {Object} $w 窗体对象
 * @param {Object} $d HTML DOM 对象
 */
(function($, $w, $d){
	"use strict";
	
	var isReady = false;
	
	/*
	 * 定义对象
	 */
	var im = {};
	
	/**
	 * 判断是否使用jQuery如果使用jQuery则继承jQuery框架
	 */
	if ($) {
		im = {} || $;
	}
	/*
	 * 版本
	 */
	im.version = 1.0;
	
	/**
	 * 系统配置
	 */
	im.config = {
		LOGIN_TIME_OUT : 4000,
		APP_KEY : '23018936',
		TRIBE_ID : ''
	};
	
	/**
	 * 定义错误处理机制
	 */
	im.error = {};
	
	/**
	 * 错误码
	 */
	im.error.code = {
		'1001': 'NOT_LOGIN', 			// 未登录
		'1002': 'TIMEOUT', 				// 超时
		'1003': 'OTHER_ERROR', 			// 其他错误,返回的数据格式不正确,拿不到期望的数据
		'1004': 'PARSE_ERROR', 			// 解析json错误
		'1005': 'NET_ERROR', 			// 网络错误
		'1006': 'KICK_OFF', 			// 被踢下线
		'1007': 'LOGIN_INFO_ERROR', 	// 登录信息错误
		'1008': 'START_ALREADY', 		// 已经开始(主要用在开启监听消息上)
		'1009': 'NO_MESSAGE', 			// 没有新消息(用在监听消息的事件返回上)
		'1010': 'PARAM_ERROR' 			// 参数错误
	};
	
	im.state = {
		LOGIN_SUCCESS : 1,
		LOGIN_ERROR : -1,
		LOGIN_TIME : 0					// 登录时间时间戳
	}
	
	/**
	 * 实现对象继承机制
	 */
	im.extend = function() {
		var options, name, src, copy, copyIsArray, clone,
			target = arguments[0] || {},
			i = 1,
			length = arguments.length,
			deep = false;
		//如果第一个值为bool值，那么就将第二个参数作为目标参数，同时目标参数从2开始计数
		if ( typeof target === "boolean" ) {
			deep = target;
			target = arguments[1] || {};
			// skip the boolean and the target
			i = 2;
		}
		// 当目标参数不是object 或者不是函数的时候，设置成object类型的
		if ( typeof target !== "object" && !im.isFunction(target) ) {
			target = {};
		}
		//如果extend只有一个函数的时候，那么将跳出后面的操作
		if ( length === i ) {
			target = this;
			--i;
		}
		for ( ; i < length; i++ ) {
			// 仅处理不是 null/undefined values
			if ( (options = arguments[ i ]) != null ) {
				// 扩展options对象
				for ( name in options ) {
					src = target[ name ];
					copy = options[ name ];
					// 如果目标对象和要拷贝的对象是恒相等的话，那就执行下一个循环。
					if ( target === copy ) {
						continue;
					}
					// 如果我们拷贝的对象是一个对象或者数组的话
					if ( deep && copy && ( im.isPlainObject(copy) || (copyIsArray = im.isArray(copy)) ) ) {
						if ( copyIsArray ) {
							copyIsArray = false;
							clone = src && im.isArray(src) ? src : [];
						} else {
							clone = src && im.isPlainObject(src) ? src : {};
						}
						//不删除目标对象，将目标对象和原对象重新拷贝一份出来。 
						target[ name ] = im.extend( deep, clone, copy );
					// 如果options[name]的不为空，那么将拷贝到目标对象上去。
					} else if ( copy !== undefined ) {
						target[ name ] = copy;
					}
				}
			}
		}
		// 返回修改的目标对象
		return target;
	}; 
	
	im.type = function (obj) {
        return obj == null ? String(obj) : class2type[{}.toString.call(obj)] || "object";
    };
    
	/**
     * isArray
     */
    im.isArray = Array.isArray ||
        function (object) {
            return object instanceof Array;
        };
    /**
     * isWindow(需考虑obj为undefined的情况)
     */
    im.isWindow = function (obj) {
        return obj != null && obj === obj.window;
    };
    /**
     * isObject
     */
    im.isObject = function (obj) {
        return im.type(obj) === "object";
    };
    /**
     * isPlainObject
     */
    im.isPlainObject = function (obj) {
        return im.isObject(obj) && !im.isWindow(obj) && Object.getPrototypeOf(obj) === Object.prototype;
    };
    /**
     * isEmptyObject
     * @param {Object} o
     */
    im.isEmptyObject = function (o) {
        for (var p in o) {
            if (p !== undefined) {
                return false;
            }
        }
        return true;
    };
    /**
     * isFunction
     */
   	im.isFunction = function (value) {
        return $.type(value) === "function";
    };
    
	/*
	 * 初始化IM功能
	 */
	im.init = new WSDK();
	im.sdk = im.init;
	
	$w.im = im;
	$w.$im = im;
	
	im.event = {};
	
	im.alert = function (e, msg) {
		switch (e) {
			case -1:
				im.get("chat_input").disabled = true;
				im.get("chat_send_btn").disabled = true;
				break;
			case 1:
				break;
			default:
				break;
		}
		$("#chat_alert").text(msg);
		$("#chat_alert").show();
		setTimeout(function(){
			$("#chat_alert").hide();
		}, 3000);
	}
	
	/**
	 * 登录
	 * @param {Object} options
	 */
	im.login = function (options) {
		var _options = {
			uid: '',
			pwd: '',
			success: function (){},
			error: function (){},
			receive: function (){}
		}
		im.extend(_options, options);
		im.sdk.Base.login({
		    uid: _options.uid,
		    appkey: im.config.APP_KEY,
		    credential: _options.pwd,
		    timeout: im.config.LOGIN_TIME_OUT,
		    success: function(data){
		    	im.alert(1, "您当前处于在线状态");
		        console.log('login success', data);
		        im.state.LOGIN_TIME = new Date().getTime();
		    	im.sdk.Event.on('START_RECEIVE_ALL_MSG', function(data){
				    
				    if (data.code == 1000) {
				    	_options.receive(data);
				    } else if (data.code == 1006) {
				    	//alert("YOU HAVE BEEN PLAYING OFFLINE : [" + im.error.code[data.code] + "]");
				    	im.alert(-1, "你已被踢下线");
				    	//_options.receive(data);
				    } else if (data.code == 1005) {
				    	im.alert(-1, "服务器或网络异常！");
				    	//_options.receive(data);
				    }
				});
				// 开启消息接收监听器
				im.sdk.Base.startListenAllMsg();
				
		    	_options.success(data);
		    },
		    error: function(error){
		    	im.state.LOGIN_TIME = -1;
		       console.log('login fail', error);
		       _options.error(error);
		       im.alert(-1, "连接聊天服务器失败！");
		    }
		});
	};
	
	/**
	 * 程序的主要入口，所有IM相关功能都必须放入当前入口的回调函数中调用，否则IM功能无法使用
	 * @param {Object} [config] 系统配置信息
	 * 		@param {String} [config.appkey] IM 阿里官方开发平台注册生成的APP唯一标识符，必须传入
	 * 		@param {String} [config.tribeId] 聊天群的ID必须传入
	 * 		@param {String} [config.uid] 当前登录用户对于IM开发平台服务器的用户账号ID
	 * 		@param {String} [config.pwd] 当前用户登录的密码
	 * 			说明：[config.uid]与[config.pwd]参数此方法不是必须传入项，当前方法如果不传入默认IM不会
	 * 				   登录服务器，且其他所有功能在未登录情况下是无法使用的。因此，在当前方法中如果未传入
	 * 				   那么在回调函数中需要手动调用系统登录方法 im.login(...) 并传入相关参数完成登录。
	 * @param {Function} [callback] 回调函数，该回调函数是所有IM程序的入口函数
	 */
	im.ready = im.event.ready = function (config, callback) {
		var _config = {
			appkey:'',
			tribeId:'',
			uid:'',
			pwd:'',
			receive:function(){}
		};
		_config = im.extend(_config, config);
		if (!(_config.tribeId || _config.uid)) {
			im.alert(-1, "无法获取用户登录信息！");
			return;
		}
		im.config.APP_KEY = _config.appkey;
		im.config.TRIBE_ID = _config.tribeId;
		isReady = true;
		if (_config.appkey == '') {
			console.log("APP KEY NOT NULL");
			return;
		}
		if (_config.uid != '' && _config.pwd != '') {
			im.login({
				uid: _config.uid,
				pwd: _config.pwd,
				success : function (data) {
					callback(im.state.LOGIN_SUCCESS, data);
				},
				error : function (error) {
					//alert("LOGIN FAILED : ERROR CODE [" + im.error.code[error.code] + "]");
					console.log(error);
					callback(im.state.LOGIN_ERROR, error);
				},
				receive : function (msg) {
					_config.receive(msg);
				}
			});
		} else {
			callback();
		}
	};
	
	im.isArray = function (obj){ 
		return (typeof obj=='object')&&obj.constructor==Array; 
	};
	
	im.get = function(elmt) {
		return document.getElementById(elmt);
	};
	
	im.click = function (elmt, callback) {
		document.getElementById(elmt).addEventListener("click", function(e){
			callback(e);
		});
	};
	
}(window.jQuery, window, document));

(function(_){
	
	/**
	 * 获取群列表
	 * @param {Object} options
	 */
	_.getTribeList = function (options) {
		var _options = {
			tribeTypes : [],
			success:function(){},
			error:function(){}
		};
		_options = _.extend(_options, options);
		_.sdk.Tribe.getTribeList({
	        tribeTypes: _options._tribeTypes,
	        success: function(data){
	            console.log(data);
	            _options.success(data);
	        },
	        error: function(error){
	            console.log(error);
	            _options.error(error);
	        }
	    });
	};
	
	/**
	 * 发送消息
	 * @param {Object} options
	 */
	_.sendMsg = function (options) {
		var _options = {
			tid: _.config.TRIBE_ID,
			msg:'',
			success:function(){},
			error:function(){}
		};
		_options = _.extend(_options, options);
		_.sdk.Tribe.sendMsg({
		    tid: _options.tid,
		    msg: _options.msg,
		    success: function(data){
			    console.log("SYS INFO [SEND MSG] : ",data);
			    _options.success(data);
		    },
		    error: function(error){
			    console.log("SYS INFO [SEND ERROR] : ", error);
			    _options.error(error);
			    var currentTimeLoginLine = (parseInt(new Date().getTime()) - parseInt(im.state.LOGIN_TIME));
			    if (currentTimeLoginLine < 30000 && error.code == 1001) {
				    im.alert(-1, "服务器异常！");
				    return;
			    }
		    }
		});
	};
	
	/**
	 * 获取群信息
	 * @param {Function} callback
	 */
	_.getTribeInfo = function (callback) {
		_.sdk.Tribe.getTribeInfo({
		    tid: _.config.TRIBE_ID,
		    success: function(data){
		        console.log("SYS INFO[GET TRIBE INFO] : ",data);
		        callback(data);
		    },
		    error: function(error){
		        console.log(error);
		        callback(error);
		    }
		});
	};
	
	var NEXT_KEY = "";
	var IS_NEXT = true;
	/**
	 * 获取历史消息
	 * @param {Function} callback
	 */
	_.getHistory = function (callback) {
		if (typeof callback == "undefined") {
			callback = function(){};
		}
		if (!IS_NEXT) {
			return null;
		}
		_.sdk.Tribe.getHistory({
		    tid: _.config.TRIBE_ID,
		    count: 5,
		    nextkey: NEXT_KEY,
		    success: function(data){
		        console.log('get history msg success', data);
				data.data.msgs = sort(data.data.msgs);
				NEXT_KEY = typeof data.data.nextKey != "undefined" ? data.data.nextKey : "";
				if (NEXT_KEY == "") {
					IS_NEXT = false;
					$(".history_msg").text("没有历史消息");
				} else {
					$(".history_msg").text("点击查看更多历史消息");
				}
				callback(data);
		    },
		    error: function(error){
		        console.log('get history msg fail', error);
		        callback(error);
		    }
		 })
	};
	
	function sort(arr){
		var _arr = new Array();
		for (var i = (arr.length - 1); i > 0; i--) {
			_arr.push(arr[i]);
		}
	    return _arr;
	}
	_.getUid = function (id){
		if (typeof id != "undefined" && id != '') {
			return _.sdk.Base.getNick(id);
		}
	}
	
	_.getUnreadMsgCount = function () {
		_.sdk.Base.getUnreadMsgCount({
		    count: 99,
		    success: function(data){
		        console.log('get unread msg count success' ,data);
		    },
		    error: function(error){
		        console.log('get unread msg count fail' ,error);
		    }
		});
	};
	
	/**
	 * 获取群成员列表
	 * @param {Object} callback
	 */
	_.getTribeMembers = function (callback) {
		if (typeof callback === "undefined") {
			return;
		}
		_.sdk.Tribe.getTribeMembers({
			tid: _.config.TRIBE_ID,
		    success: function(data){
		        console.log(data);
		        callback(data);
		    },
		    error: function(error){
		        console.log(error);
		        callback(error);
		    }
		});
		
	}
	
	_.stopListenAllMsg = function () {
		_.sdk.Base.stopListenAllMsg();
	}
	
	_.getImUserInfo = function (imUserId) {
		var user;
		$.ajax({
			type:"post",
			//url:"http://121.40.251.190:8080/wlxy/login/queryImUserInfo.do?detype=android",
			url:"http://" + getServer() + "/login/queryImUserInfo.do?detype=android",
			//url:"http://yxxt.cdcas.edu.cn/wlxy/login/queryImUserInfo.do?detype=android",
			async:false,
			data : {
				"imUserId" : imUserId
			},
			success : function (result) {
				if (result) {
					result = JSON.parse(result.substring(5, result.length - 1));
					if (result.imUser) {
						user = result.imUser;
					}
				}
			},
			error : function () {
				
			}
		});
		return user;
	};
	
	_.getImUserName = function (imUserId) {
		var user = _.getImUserInfo(imUserId);
		return typeof user == "undefined" ? "" : user.im_nick;
	};
	
	_.pushMsg = function (imId, tribeId, msg) {
//		var _url = "http://121.40.251.190:8080/wlxy/notice/pushMsg.do";
		var _url = "http://" + getServer() + "/notice/gexinPushMsg.do";
		$.ajax({
			type:"get",
			async:true,
			url:_url,
			contentType: "application/x-www-form-urlencoded; charset=utf-8",
			data : {
				"sendImUserId" : imId,
				"userTribeId" : tribeId,
				"msgContent" : msg
			},
			success : function (result) {
				console.log(result);
//				im.alert(1, "推送测试：" + result);
			},
			error : function () {
			}
		});
	};

}(im));

