/*!
 *	wuxl
 *  Date: 2015-07-06
 *  工具集
 */
(function($) {
	var _Util = {
		goPage: function(url, params) {
			var defaultParam = {
				refresh: true, //是否刷新已存在page
				aniShow: 'slide-in-right', //页面显示动画，默认为”slide-in-right“；
				duration: 200 //页面动画持续时间
			};
			defaultParam.pageId = url + '-id';
			var config = mui.extend(true, defaultParam, params || {});
			//console.log('viewId='+config.pageId)
			//console.log('refresh='+config.refresh)
			if (config.refresh) {
				var hisPage = plus.webview.getWebviewById(config.pageId);
				plus.webview.close(hisPage);
			}
			mui.openWindow({
				url: url,
				id: config.pageId,
				extras: config,
				show: {
					autoShow: true, //页面loaded事件发生后自动显示，默认为true
					aniShow: config.aniShow, //页面显示动画，默认为”slide-in-right“；
					duration: config.duration //页面动画持续时间，Android平台默认100毫秒，iOS平台默认200毫秒；
				},
				waiting: {
					autoShow: false, //自动显示等待框，默认为true
					title: '正在载入...' //等待对话框上显示的提示内容
				}
			});
		},
		alertJSON: function(json) {
			alert(JSON.stringify(json));
		},
		/***
		 * 将URL中串?param1=value1&param2=value2
		 * 转换成对象数组
		 */
		getUrlParam: function(string) {
			var obj = new Array();
			if (string.indexOf("?") != -1) {
				string = string.substr(string.indexOf("?") + 1);
			}
			var strs = string.split("&");
			for (var i = 0; i < strs.length; i++) {
				var tempArr = strs[i].split("=");
				obj[i] = decodeURIComponent(tempArr[1]);
			}
			return obj;
		},
		/***
		 * 将URL中串?param1=value1&param2=value2
		 * 转换成对象{param1 : 'value1', param2 : 'value2'}
		 */
		getUrlObj: function(string) {
			var obj = new Object();
			if (string.indexOf("?") != -1) {
				string = string.substr(string.indexOf("?") + 1);
			}
			var strs = string.split("&");
			for (var i = 0; i < strs.length; i++) {
				var tempArr = strs[i].split("=");
				obj[tempArr[0]] = decodeURIComponent(tempArr[1]);
			}
			return obj;
		},
		/**
		 * 获得当前url参数值
		 * @param name 参数名
		 */
		getUrlParamByName: function(name) {
			return _Util.getUrlObj(document.URL)[name];
		},
		/**
		 * 电话号码判断：
		 * true：表示传入的号码为正确号码
		 * false：传入号码为错误号码
		 */
		checkMobile: function(value) {
			var reg_flag = false;
			var reg = /(^1\d{10}$)|(^(\d{4}-|\d{3}-)?(\d{8}|\d{7})$)/;
			if (reg.test(value)) {
				reg_flag = true;
			}
			return reg_flag;
		},
		/**
		 * 数据大小转换
		 * @param {Object} bytes
		 */
		bytesToSize: function(bytes) {
			if (bytes === 0) return '0 B';
			var k = 1024, // or 1024
				sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
				i = Math.floor(Math.log(bytes) / Math.log(k));
			return (bytes / Math.pow(k, i)).toPrecision(3) + ' ' + sizes[i];
		},
		/**
		 * 科学计算转换为正常数值
		 */
		scienceNum: function(value) {
			if (value) {
				var num = 0;
				if ((num = value.indexOf('E')) != -1 || (num = value.indexOf('e')) != -1) {
					var doubleStr = value.substring(0, num);
					var eStr = value.substring(num + 1, value.length);
					eStr = parseInt(eStr);
					var doubleStrList = doubleStr.split('.');
					var doubleStr1 = doubleStrList[0];
					var doubleStr2 = doubleStrList[1];

					if (doubleStr2.length > eStr) {
						var nums = doubleStr2.substring(0, eStr);
						var nume = doubleStr2.substring(eStr, doubleStr2.length);
						doubleStr = doubleStr1 + nums + '.' + nume;
					} else if (doubleStr2.length < eStr) {
						var indexNum = eStr - doubleStr2.length;
						//用0补齐
						var str = '';
						for (var i = 0; i < indexNum; i++) {
							str += '0';
						}
						doubleStr = doubleStr1 + doubleStr2 + str;
					} else {
						doubleStr = doubleStr1 + doubleStr2;
					}
					value = doubleStr;
					//千分位
				}
			}
			return value;
		},
		/**
		 * 数值变为千分位
		 * @param {Object} str
		 */
		qfwcount: function(str) {
			//var str='12345678.111';
			//小数点后的数字
			var floatStr = '';
			//小数点前的数字
			var strStart = '';
			var num = 0;
			if ((num = str.indexOf('.')) != -1) {
				var strList = str.split('.');
				strStart = strList[0];
				floatStr = strList[1];
			}
			var strNew = '';
			var forLength = strStart.length / 3;
			for (var i = 0; i < forLength; i++) {
				//结尾
				var strEndNow = strStart.substring(strStart.length - 3, strStart.length);
				var strStartNow = strStart.substring(0, strStart.length - 3);
				strStart = strStartNow;
				if (strNew != '') {
					strNew = ',' + strNew;
				}
				strNew = strEndNow + strNew;
			}
			if (floatStr != '') {
				strNew = strNew + '.' + floatStr;
			}
			return strNew;
		},
		/**
		 * 获取当前时间
		 */
		getNowFormatDate : function(){
			var date = new Date();
		    var seperator1 = "-";
		    var seperator2 = ":";
		    var month = date.getMonth() + 1;
		    var strDate = date.getDate();
		    if (month >= 1 && month <= 9) {
		        month = "0" + month;
		    }
		    if (strDate >= 0 && strDate <= 9) {
		        strDate = "0" + strDate;
		    }
		    var currentdate = date.getFullYear() + seperator1 + month + seperator1 + strDate
		            + " " + date.getHours() + seperator2 + date.getMinutes()
		            + seperator2 + date.getSeconds();
		    return currentdate;
		},
		getTimeDF : function(dt1,dt2){
			var d1 = dt1.split(" ")[0];//天段
			var t1 = dt1.split(" ")[1];//时段
			var y1 = d1.split("-")[0];//年
			var m1 = d1.split("-")[1];//月
			var day1 = d1.split("-")[2];//天
			var h1 = t1.split(":")[0];//小时
			var min1 = t1.split(":")[1];//分钟
			var ms1 = t1.split(":")[2];//秒
			var d2 = dt2.split(" ")[0];//天段
			var t2 = dt2.split(" ")[1];//时段
			var y2 = d2.split("-")[0];//年
			var m2 = d2.split("-")[1];//月
			var day2 = d2.split("-")[2];//天
			var h2 = t2.split(":")[0];//小时
			var min2 = t2.split(":")[1];//分钟
			var ms2 = t2.split(":")[2];//秒
			if(1*y2 - 1*y1 > 0){
				return "很早";
			}else if(1*m2 - 1*m1 > 0){
				return (1*m2 - 1*m1)+"月前";
			}else if(1*day2 - 1*day1 > 0){
				return (1*day2 - 1*day1)+"天前";
			}else if(1*h2 - 1*h1 > 0){
				return (1*h2 - 1*h1)+"小时前";
			}else if(1*min2 - 1*min1 > 0){
				return (1*min2 - 1*min1)+"分钟前";
			}else if(1*ms2 - 1*ms1 > 0){
				return (1*ms2 - 1*ms1)+"秒前";
			}
		},
		getDayDF:function(sDate1,sDate2){//sDate1和sDate2是2006-12-18格式
			var aDate,oDate1,oDate2,iDays;  
	        aDate=sDate1.split("-");  
	        oDate1=new Date(aDate[1]+'-'+aDate[2]+'-'+aDate[0]); //转换为12-18-2006格式  
	        aDate=sDate2.split("-");  
	        oDate2=new Date(aDate[1]+'-'+aDate[2]+'-'+aDate[0]); 
	        iDays=parseInt(Math.abs(oDate1-oDate2)/1000/60/60/24); //把相差的毫秒数转换为天数  
	        return iDays; 
		},
		isPositiveNum:function(str){//是否为正整数:true-正整数；false-不是正整数
			var re = /^[0-9]*[1-9][0-9]*$/ ; 
			return re.test(str); 
		}
	};
	_App.util = _Util;
	//alert('util init finished!');
	//console.log('util init finished!');
}(mui))